@@ -1,13 +1,11 @@
 # -*- coding: utf-8 -*-
-"""
-Created on Thu Sep 17 09:17:58 2020
 
-@author: Morgenthaler
-"""
-
-from ruamel.yaml import YAML
+import ruamel.yaml
+import yaml
 import pandas as pd
 import copy
+import configparser
+import os
 
 def get_default_config():
     """
@@ -89,12 +87,17 @@ def prepare_csv(data):
         df0 = pd.DataFrame(index=pd.date_range(start=str(y), end=str(y)+'-12-31 23', freq='H'))
         for i, row in data[data.ReportingYear == y].iterrows():
             FacilityIDDict[row.FacilityID] = row.FacilityName.replace(' ', '_').replace('.', '_').replace(',', '_').replace('-', '_').replace('\&', '_').replace('ä', 'ae').replace('ö', 'oe').replace('ü', 'ue')
-            column_name = row.FacilityID
+            column_name = row.FacilityReportID
+            # Warum FacilityID, ist ja genausowenig unique
+            # Wäre FacilityReportID nicht eindeutig?
+            # GEGENCHECKEN !!!!
+            df.loc[str(y), column_name] = row.TotalQuantity / len(df0)
+            # NEU EINGEFÜGT BZW ALTEN CODE GENOMMEN
             coords[column_name] = (row.Lat, row.Long)
     return df, coords, FacilityIDDict
 
 
-def export_calliope(data, sc=0.07):
+def export_calliope(data, path=None, yamlfilename='emipy2calliope.yaml', csvfilename='emipy2calliope.csv', sc=0.07):
     """
     Exports the data to a csv file readable by the calliope project.
 
@@ -102,6 +105,12 @@ def export_calliope(data, sc=0.07):
     ----------
     data : DataFrame
         Data that are to be exported.
+    path : String, optional
+        Path to the storage place. If None is given, emipy uses the path, stored in the config file. The default ist None.
+    yamlfilename : String, optional
+        filename for the yaml file. The default is emipy2calliope.yaml.
+    csvfilename : String, optional
+        filename for the csv file. The default is emipy2calliope.csv.
     sc : int, optional
         monetary cost factor. The default is 0.07.
 
@@ -114,22 +123,27 @@ def export_calliope(data, sc=0.07):
     df, coords, FacilityIDDict = prepare_csv(data)
     d = get_default_config()
     config = {}
-    
+
     for c in df.columns:
         config[c] = copy.deepcopy(d)
-        s = 'emipy.csv:' + str(c)
+        s = 'file=emipy.csv:' + str(c)
+        config[c]['coordinates'] = {'lat': coords.get(c)[0], 'lon': coords.get(c)[1]}
         config[c]['techs']['co2_supply']['constraints']['resource'] = s
         config[c]['techs']['co2_supply']['constraints']['energy_cap_max'] = float(df.loc[:, c].max())
-        config[c]['coordinates'] = {'lat': coords.get(c)[0], 'lon': coords.get(c)[1]}
         config[c]['techs']['co2_supply']['costs']['monetary']['om_prod'] = sc
 
-    with open('emipy2calliope.yaml', 'w') as f:
-        yaml=YAML()
-        yaml.dump(config, f, default_flow_style=False)
+    yaml = ruamel.yaml.YAML()
+    yaml.indent(mapping=4, sequence=4, offset=2)
 
-    df.to_csv('emipy.csv')
+    if path == None:
+        configuration = configparser.ConfigParser()
+        configuration.read(os.path.join(os.path.dirname(os.path.realpath(__file__)), 'configuration\\configuration.ini'))
+        path = configuration['PATH']['path']
+        path = os.path.join(path, 'ExportData')
+
+    with open(os.path.join(path, yamlfilename), 'w') as f:
+        yaml.dump(config, f)
+
+    df.to_csv(os.path.join(path, csvfilename))
 
     return None
-
-
-    
\ No newline at end of file
