@@ -282,7 +282,9 @@ def init_emipy_project(path, Resolution=10, force_rerun=False):
     download_PollutionData(path=path)
     print('Pollution data successfully downloaded and extracted.')
     download_MapFiles(path=path, Resolution=Resolution)
+    print('Map data successfully downloaded and extractet.')
     download_NACE_TransitionTables(path)
+    print('Transition tables succesfully downloaded.')
     pickle_rawdata(path=path, force_rerun=force_rerun)
     merge_frompickle(path=path, force_rerun=force_rerun)
     print('Data merged and pickled.')
